--
-- File version: 22
-- Project: 24
--
if not TinyMeleeStats then return end

local L = LibStub("AceLocale-3.0"):GetLocale("TinyMeleeStats")
local media = LibStub:GetLibrary("LibSharedMedia-3.0")

TinyMeleeStats.fonteffects = {
	["none"] = L["NONE"],
	["OUTLINE"] = L["OUTLINE"],
	["THICKOUTLINE"] = L["THICKOUTLINE"],
}

function TinyMeleeStats:Options()
	local options = {
		name = "TinyMeleeStats",
	    handler = TinyMeleeStats,
	    type = 'group',
	    args = {
			reset = {
				name = L["Reset position"],
				desc = L["Resets the frame's position"],
				type = 'execute',
				func = function() tmsframe:ClearAllPoints() tmsframe:SetPoint("CENTER", UIParent, "CENTER") end,
				disabled = function() return InCombatLockdown() end,
				order = 1,
			},
			lock = {
				name = L["Lock Frame"],
				desc = L["Locks the position of the text frame"],
				type = 'toggle',
				get = function() return self.db.char.FrameLocked end,
				set = function(info, value)				
					if(value) then
						self.db.char.FrameLocked = true
						tmsframe:SetMovable(false)
						fixed = "|cffFF0000"..L["Text is fixed. Uncheck Lock Frame in the options to move!"].."|r"
						tmsframe:SetScript("OnDragStart", function() DEFAULT_CHAT_FRAME:AddMessage(fixed) end)
					else
						self.db.char.FrameLocked = false
						tmsframe:SetMovable(true)
						tmsframe:SetScript("OnDragStart", function() tmsframe:StartMoving() end)
						tmsframe:SetScript("OnDragStop", function()	tmsframe:StopMovingOrSizing() self.db.char.xPosition = tmsframe:GetLeft() self.db.char.yPosition = tmsframe:GetBottom()	end)
					end
				end,
				disabled = function() return InCombatLockdown() end,
				order = 2,
			},
			text = {
				name = L["Text"],
				desc = L["Text settings"],
				type = 'group',
				order = 3,
				args = {
					oocalpha = {
						name = L["Text Alpha"].." "..L["out of combat"],
						desc = L["Alpha of the text"].." ("..L["out of combat"]..")",
						width = 'full',
						type = 'range',
						min = 0,
						max = 1,
						step = 0.01,
						isPercent = true,
						get = function() return self.db.char.outOfCombatAlpha end,
						set = function(info, newValue)
							self.db.char.outOfCombatAlpha = newValue
							tmsframe:SetAlpha(self.db.char.outOfCombatAlpha)
						end,
						disabled = function() return InCombatLockdown() end,
						order = 1,
					},
					icalpha = {
						name = L["Text Alpha"].." "..L["in combat"],
						desc = L["Alpha of the text"].." ("..L["in combat"]..")",
						width = 'full',
						type = 'range',
						min = 0,
						max = 1,
						step = 0.01,
						isPercent = true,
						get = function() return self.db.char.inCombatAlpha end,
						set = function(info, newValue)
							self.db.char.inCombatAlpha = newValue
							tmsframe:SetAlpha(self.db.char.inCombatAlpha)
						end,
						disabled = function() return InCombatLockdown() end,
						order = 2,
					},
					barfontsize = {
						name = L["Font size"],
						width = 'full',
						type = 'range',
						min = 6,
						max = 32,
						step = 1,
						get = function() return self.db.char.Size end,
						set = function(info, newValue)
							self.db.char.Size = newValue
							local font = media:Fetch("font", self.db.char.Font)
							tmsstring:SetFont(font, self.db.char.Size, self.db.char.FontEffect)
						end,
						order = 3,
					},
					font = {
						name = L["Font"],
						type = 'select',
						get = function() return self.db.char.Font end,
						set = function(info, newValue)
							self.db.char.Font = newValue
							local font = media:Fetch("font", self.db.char.Font)
							tmsstring:SetFont(font, self.db.char.Size, self.db.char.FontEffect)
						end,
						values = self.fonts,
						order = 4,
					},
					fonteffect = {
						name = L["Font border"],
						type = 'select',
						get = function() return self.db.char.FontEffect end,
						set = function(info, newValue)
							self.db.char.FontEffect = newValue
							local font = media:Fetch("font", self.db.char.Font)
							tmsstring:SetFont(font, self.db.char.Size, self.db.char.FontEffect)
						end,
						values = self.fonteffects,
						order = 5,
					},
					vertical = {
						name = L["Display stats vertically"],
						desc = L["Whether or not to show stats vertically"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.vertical end,
						set = function(info, value)
							if(value) then
								self.db.char.Style.vertical = true
							else
								self.db.char.Style.vertical = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 6,
					},
					record = {
						name = L["Announce records"],
						desc = L["Whether or not to display a message when a record is broken"],
						type = 'toggle',
						get = function() return self.db.char.RecordMsg end,
						set = function(info, value)
							if(value) then
								self.db.char.RecordMsg = true
							else
								self.db.char.RecordMsg = false
							end
						end,
						disabled = function() return InCombatLockdown() end,
						order = 7,
					},
					labels = {
						name = L["Show labels"],
						desc = L["Whether or not to show labels for each stat"],
						type = 'toggle',
						get = function() return self.db.char.Style.labels end,
						set = function(info, value)
							if(value) then
								self.db.char.Style.labels = true
							else
								self.db.char.Style.labels = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 8,
					}
				},
			},
			style = {
				name = L["Stats"],
				desc = L["Select which stats to show"],
				type = 'group',
				order = 2,
				args = {
					hader = {
						name = L["Stats"],
						type = 'header',
						order = 1,
					},
					spaceline3 = {
						name = "\n",
						type = 'description',
						order = 2,
					},
					ap = {
						name = L["Attack Power"],
						desc = L["Attack Power"].." "..L["show/hide"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.Ap end,
						set = function(info, value)				
							if(value) then
								self.db.char.Style.Ap = true
							else
								self.db.char.Style.Ap = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 3,
					},
					crit = {
						name = L["Critical Chance"],
						desc = L["Critical Chance"].." "..L["show/hide"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.Crit end,
						set = function(info, value)				
							if(value) then
								self.db.char.Style.Crit = true
							else
								self.db.char.Style.Crit = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 4,
					},
					hit = {
						name = L["Hit rating"],
						desc = L["Hit rating"].." "..L["show/hide"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.Hit end,
						set = function(info, value)				
							if(value) then
								self.db.char.Style.Hit = true
							else
								self.db.char.Style.Hit = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 5,
					},
					speed = {
						name = L["Weapon speed"],
						desc = L["Weapon speed"].." "..L["show/hide"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.Speed end,
						set = function(info, value)				
							if(value) then
								self.db.char.Style.Speed = true
							else
								self.db.char.Style.Speed = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 6,
					},
					arp = {
						name = L["Armor Penetration"],
						desc = L["Armor Penetration"].." "..L["show/hide"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.Arp end,
						set = function(info, value)				
							if(value) then
								self.db.char.Style.Arp = true
							else
								self.db.char.Style.Arp = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 7,
					},
					spaceline4 = {
						name = "\n",
						type = 'description',
						order = 8,
					},
					resetrecords = {
						name = L["Reset records"],
						desc = L["Clears your current records"],
						type = 'execute',
						func = function()
							self.db.char.HighestAp = 0
							self.db.char.HighestCrit = 0
							self.db.char.FastestMh = 500
							self.db.char.FastestOh = 500
							self.db.char.HighestHit = 0
							self.db.char.HighestArp = 0
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 9,
					},
				},
			},
		},
	}
	return options
end
