--         --------------------------------------------
--        |  TinyMeleeStats by TheVaan and ArcaneMagus |
--         --------------------------------------------
--
-- File version: 24
-- Project: 24
--

local AceAddon = LibStub("AceAddon-3.0")
local media = LibStub:GetLibrary("LibSharedMedia-3.0")
TinyMeleeStats = AceAddon:NewAddon("TinyMeleeStats", "AceConsole-3.0", "AceEvent-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("TinyMeleeStats")

local ldb = LibStub:GetLibrary("LibDataBroker-1.1");
local TMSBroker = ldb:NewDataObject("TinyMeleeStats", { 
	type = "data source",
	label = "TinyMeleeStats", 
	icon = "Interface\\Icons\\Ability_Racial_ShadowMeld",
	text = "--"
	}
	)

	
TinyMeleeStats.fonts = {}

TinyMeleeStats.defaults = {
	char = {
		Font = "Vera",
		FontEffect = "none",
		Size = 12,
		FrameLocked = true,
		yPosition = 200,
		xPosition = 200,
		inCombatAlpha = 1,
		outOfCombatAlpha = .3,
		RecordMsg = true,
		HighestAp = 0,
		HighestCrit = 0,
		FastestMh = 500,
		FastestOh = 500,
		HighestHit = 0,
		HighestArp = 0,
		Style = {
			Ap = true,
			Crit = true,
			Speed = true,
			Hit = false,
			Arp = false,
			showRecords = true,
			vertical = false,
			labels = false
		},
	}
}

tmsframe = CreateFrame("Frame","TinyMeleeStatsFrame",UIParent)
tmsframe:SetWidth(100)
tmsframe:SetHeight(15)
tmsframe:SetFrameStrata("BACKGROUND")
tmsframe:EnableMouse(true)
tmsframe:RegisterForDrag("LeftButton")

tmsstring = tmsframe:CreateFontString()
tmsstring:SetFontObject(GameFontNormal)
tmsstring:SetPoint("CENTER", tmsframe)
tmsstring:SetJustifyH("CENTER")
tmsstring:SetJustifyV("MIDDLE")

function TinyMeleeStats:OnInitialize()
	local AceConfigReg = LibStub("AceConfigRegistry-3.0")
	local AceConfigDialog = LibStub("AceConfigDialog-3.0")
	
	self.db = LibStub("AceDB-3.0"):New("TinyMeleeStats", TinyMeleeStats.defaults, "char")
	LibStub("AceConfig-3.0"):RegisterOptionsTable("TinyMeleeStats", self:Options(), "tmscmd")
	media.RegisterCallback(self, "LibSharedMedia_Registered")
	
	self:RegisterChatCommand("tms", function() AceConfigDialog:Open("TinyMeleeStats") end)	
	self:RegisterChatCommand("tinymeleestats", function() AceConfigDialog:Open("TinyMeleeStats") end)	
	self.optionsFrame = AceConfigDialog:AddToBlizOptions("TinyMeleeStats", "TinyMeleeStats")
	self.db:RegisterDefaults(self.defaults)
	local version = GetAddOnMetadata("TinyMeleeStats","Version")
	local loaded = L["Open the configuration menu with /tms or /tinymeleestats"].."|r"
	DEFAULT_CHAT_FRAME:AddMessage("|cffffd700TinyMeleeStats |cff00ff00~v"..version.."~|cffffd700: "..loaded)
end

function TinyMeleeStats:OnEnable()
	self:LibSharedMedia_Registered()
	self:RegisterEvent("PLAYER_ENTERING_WORLD", "OnEvent")
	self:RegisterEvent("ADDON_LOADED", "OnEvent")
	self:RegisterEvent("VARIABLES_LOADED", "OnEvent")
	self:RegisterEvent("UNIT_ATTACK_POWER", "OnEvent")
	self:RegisterEvent("UNIT_ATTACK_SPEED", "OnEvent")
	self:RegisterEvent("UNIT_AURA", "OnEvent")
	self:RegisterEvent("UPDATE_SHAPESHIFT_FORM", "OnEvent")
	self:RegisterEvent("UNIT_INVENTORY_CHANGED", "OnEvent")
	self:RegisterEvent("UNIT_LEVEL", "OnEvent")
	self:RegisterEvent("PLAYER_REGEN_ENABLED", "OnEvent")
	self:RegisterEvent("PLAYER_REGEN_DISABLED", "OnEvent")
	self:RegisterEvent("PLAYER_TALENT_UPDATE", "OnEvent")
end

function TinyMeleeStats:LibSharedMedia_Registered()
	media:Register("font", "BaarSophia", [[Interface\Addons\TinyMeleeStats\Fonts\BaarSophia.ttf]])
	media:Register("font", "LucidaSD", [[Interface\Addons\TinyMeleeStats\Fonts\LucidaSD.ttf]])
	media:Register("font", "Teen", [[Interface\Addons\TinyMeleeStats\Fonts\Teen.ttf]])
	media:Register("font", "Vera", [[Interface\Addons\TinyMeleeStats\Fonts\Vera.ttf]])
	
	for k, v in pairs(media:List("font")) do
		self.fonts[v] = v
	end
end

function TinyMeleeStats:OnEvent(event, arg1)
	if (event == "ADDON_LOADED") then
		tmsframe:SetPoint("BOTTOMLEFT", UIParent, "BOTTOMLEFT", self.db.char.xPosition, self.db.char.yPosition)
		local font = media:Fetch("font", self.db.char.Font)
		tmsstring:SetFont(font, self.db.char.Size, self.db.char.FontEffect)
	end
		if ((event == "PLAYER_REGEN_ENABLED") or (event == "PLAYER_ENTERING_WORLD")) then
		tmsframe:SetAlpha(self.db.char.outOfCombatAlpha)
	end
	if (event == "PLAYER_REGEN_DISABLED") then
		tmsframe:SetAlpha(self.db.char.inCombatAlpha)
	end
	if (self.db.char.FrameLocked == true) then 
		local fixed = L["Text is fixed. Uncheck Lock Frame in the options to move!"]
		tmsframe:SetScript("OnDragStart", function() DEFAULT_CHAT_FRAME:AddMessage(fixed) end)
	end
  	self:Stats()
end

function TinyMeleeStats:Stats()
	local style = self.db.char.Style
	local base, buff, debuff = UnitAttackPower("player")
	local pow = base + buff + debuff
	local crit = string.format("%.2f", GetCritChance("player"))
	local mainSpeed, offSpeed = UnitAttackSpeed("player")
	local speed = 0
	local hit = string.format("%.2f", GetCombatRatingBonus(CR_HIT_MELEE))
	local arp = string.format("%.2f", GetArmorPenetration("player"))
	local recordBrocken = "|cffFF0000"..L["Record broken!"]..": "

	if (offSpeed == nil) then
		if (mainSpeed > 0) then
			mainSpeed = string.format("%.2f", mainSpeed)
			speed = mainSpeed
			if (tonumber(mainSpeed) < tonumber(self.db.char.FastestMh)) then self.db.char.FastestMh = mainSpeed end
		else
			speed = 0
			mainSpeed = 0
		end
	else
		if (mainSpeed > 0) then
			mainSpeed = string.format("%.2f", mainSpeed)
			offSpeed = string.format("%.2f", offSpeed)
			speed = mainSpeed.."s "..offSpeed
			if (tonumber(mainSpeed) < tonumber(self.db.char.FastestMh)) then self.db.char.FastestMh = mainSpeed end
			if (tonumber(offSpeed) < tonumber(self.db.char.FastestOh)) then self.db.char.FastestOh = offSpeed end
		else
			speed = 0
			mainSpeed = 0
			offSpeed = 0
		end
	end
	
	if (tonumber(pow) > tonumber(self.db.char.HighestAp)) then
		self.db.char.HighestAp = pow
		if (self.db.char.RecordMsg == true) then
			DEFAULT_CHAT_FRAME:AddMessage(recordBrocken.."|cffFF0000"..L["Attack Power"]..": |c00ffef00"..self.db.char.HighestAp.."|r")
		end
	end
	if (tonumber(crit) > tonumber(self.db.char.HighestCrit)) then
		self.db.char.HighestCrit = crit
		if (self.db.char.RecordMsg == true) then
			DEFAULT_CHAT_FRAME:AddMessage(recordBrocken.."|cffFF0000"..L["Critical Chance"]..": |c00ffef00"..self.db.char.HighestCrit.."|r")
		end
	end
	if (tonumber(hit) > tonumber(self.db.char.HighestHit)) then
		self.db.char.HighestHit = hit
		if (self.db.char.RecordMsg == true) then
			DEFAULT_CHAT_FRAME:AddMessage(recordBrocken.."|cffFF0000"..L["Hit rating"]..": |c00ffef00"..self.db.char.HighestHit.."|r")
		end
	end
	if (tonumber(arp) > tonumber(self.db.char.HighestArp)) then
		self.db.char.HighestArp = arp
		if (self.db.char.RecordMsg == true) then
			DEFAULT_CHAT_FRAME:AddMessage(recordBrocken.."|cffFF0000"..L["Armor Penetration"]..": |c00ffef00"..self.db.char.HighestArp.."|r")
		end
	end

			
	if (offSpeed == nil) then
		fastestSpeed = self.db.char.FastestMh
	else
		fastestSpeed = self.db.char.FastestMh.."s "..self.db.char.FastestOh		
	end

	local stat = ""
	local horizRecords = ""
	local seperator = ""
	if (style.vertical) then
		seperator = "|n"
	else
		seperator = " "
	end
	
	if (style.Ap == true) then
		stat = "|c00ffef00"
		if (style.labels) then
			stat = stat..L["Ap:"].." "
			horizRecords = horizRecords.."|c00ffef00"..L["Ap:"].." "
		end
		stat = stat..pow
		if (style.showRecords) then
			if (style.vertical) then
				stat = stat.." |c00ffef00("..self.db.char.HighestAp..")"
			else
				horizRecords = horizRecords.."|c00ffef00"..self.db.char.HighestAp..seperator
			end
		end
		stat = stat..seperator
	end
	if (style.Crit == true) then
		stat = stat.."|c00ff00ff"
		if (style.labels) then
			stat = stat..L["Crit:"].." "
			horizRecords = horizRecords.."|c00ff00ff"..L["Crit:"].." "
		end
		stat = stat..crit.."%"
		if (style.showRecords) then
			if (style.vertical) then
				stat = stat.." |c00ff00ff("..self.db.char.HighestCrit.."%)"
			else
				horizRecords = horizRecords.."|c00ff00ff"..self.db.char.HighestCrit.."%"..seperator
			end
		end
		stat = stat..seperator
	end
	if (style.Hit == true) then
		stat = stat.." |c0000CD00"
		if (style.labels) then
			stat = stat..L["Hit:"].." "
			horizRecords = horizRecords.."|c0000CD00"..L["Hit:"].." "
		end
		stat = stat..hit.."%"
		if (style.showRecords) then
			if (style.vertical) then
				stat = stat.." |c0000CD00("..self.db.char.HighestHit.."%)"
			else
				horizRecords = horizRecords.."|c0000CD00"..self.db.char.HighestHit.."%"..seperator
			end
		end
		stat = stat..seperator
	end
	if (style.Speed == true) then
		stat = stat.." |c001E90FF"
		if (offSpeed == nil) then
			if (style.labels) then
				stat = stat..L["Speed:"].." "
				horizRecords = horizRecords.."|c001E90FF"..L["Speed:"].." "
			end
			stat = stat..speed
			if (style.showRecords) then
				if (style.vertical) then
					stat = stat.." |c001E90FF("..fastestSpeed.."s)"
				else
					horizRecords = horizRecords.."|c001E90FF"..fastestSpeed.."s"..seperator
				end
			end
			stat = stat..seperator
		else
			if (style.vertical) then
				if (style.labels) then
					stat = stat..L["Mh:"].." "
				end
				stat = stat..mainSpeed
				if (style.showRecords) then
					stat = stat.." |c001E90FF("..self.db.char.fastestMh.."s)"--"..self.db.char.fastestOh.."s
				end
				stat = stat..seperator
				if (style.labels) then
					stat = stat..L["Oh:"].." "
				end
				stat = stat..offSpeed
				if (style.showRecords) then
					stat = stat.." |c001E90FF("..self.db.char.fastestOh.."s)"
				end
				stat = stat..seperator
			else
				if (style.labels) then
					stat = stat..L["Speed:"].." "
					horizRecords = horizRecords.."|c001E90FF"..L["Speed:"].." "
				end
				stat = stat..speed
				if (style.showRecords) then
					horizRecords = horizRecords.."|c001E90FF"..fastestSpeed.."s"..seperator
				end
				stat = stat..seperator
			end
		end
	end
	if (style.Arp == true) then
		stat = stat.." |c000033CC"
		if (style.labels) then
			stat = stat..L["Arp:"].." "
			horizRecords = horizRecords.."|c000033CC"..L["Arp:"].." "
		end
		stat = stat..arp
		if (style.showRecords) then
			if (style.vertical) then
				stat = stat.." |c000033CC("..self.db.char.HighestArp..")"
			else
				horizRecords = horizRecords.."|c000033CC"..self.db.char.HighestArp..seperator
			end
		end
		stat = stat..seperator
	end

	if (not style.vertical and style.showRecords) then
		stat = stat.."\n"..horizRecords
	end
	
	tmsstring:SetText(stat)
	TMSBroker.text = stat
end
